import jm from 'json-msg';
export { default } from 'json-msg';
import { useState, useEffect, useCallback } from 'react';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function getSelectedValues(options) {
    return Array.from(options)
        .filter(function (el) { return el.selected; })
        .map(function (el) { return el.value; });
}
function useForm(initialData, schema, options) {
    if (initialData === void 0) { initialData = {}; }
    if (options === void 0) { options = {}; }
    var _a = options.trim, trim = _a === void 0 ? false : _a, _b = options.validateOnChange, validateOnChange = _b === void 0 ? true : _b, showAllErrors = options.showAllErrors, validateOnMount = options.validateOnMount;
    var _c = useState(initialData), data = _c[0], setData = _c[1];
    var _d = useState({}), errors = _d[0], setErrors = _d[1];
    function validateData(data) {
        if (!schema)
            return null;
        var errorMsg = jm.validate(data, schema, {
            abortEarly: false,
            showAllErrors: showAllErrors
        });
        if (errorMsg)
            setErrors(errorMsg);
        else
            setErrors({});
        return errorMsg;
    }
    useEffect(function () {
        validateOnMount && validateData(data);
    }, []);
    var handleChange = useCallback(function (e) {
        var _a = e.target, type = _a.type, name = _a.name, val = _a.value, checked = _a.checked, options = _a.options, multiple = _a.multiple;
        var parseNum;
        var value = /number|range/.test(type)
            ? (parseNum = parseFloat(val), isNaN(parseNum) ? '' : parseNum)
            : /checkbox/.test(type) // checkbox
                ? checked
                : options && multiple // <select multiple>
                    ? getSelectedValues(options)
                    : val;
        var schemaName = schema && schema[name];
        if (trim && typeof value === 'string')
            value = value.trim();
        if (validateOnChange && schemaName && !schemaName.config.sameAs) {
            schemaName.label = schemaName.label || name;
            var errorMsg_1 = jm.validate(value, schemaName, { showAllErrors: showAllErrors });
            setErrors(function (error) {
                var _a;
                if (errorMsg_1)
                    return __assign(__assign({}, error), (_a = {}, _a[name] = errorMsg_1, _a));
                error && delete error[name];
                return error;
            });
        }
        setData(function (prevData) {
            var _a;
            return (__assign(__assign({}, prevData), (_a = {}, _a[name] = value, _a)));
        });
    }, []);
    var handleSubmit = useCallback(function (callback) {
        return function (e) {
            e.preventDefault();
            // Access data from setData since this function is wrap on useCallback
            // This is better than recomputing Everytime the data changes
            setData(function (prevData) {
                var errorMsg = validateData(prevData);
                if (errorMsg)
                    return prevData;
                callback && callback(prevData);
                return prevData;
            });
        };
    }, []);
    return { data: data, handleChange: handleChange, handleSubmit: handleSubmit, errors: errors };
}

export { useForm };
//# sourceMappingURL=index.es.js.map
